# These data files were originally inside a MySQL database. This SQL file recreates the table structure.

# `id` matches `word_capitals.id`
# `name` is a human-friendly name for the entity
CREATE TABLE `names_disambiguated` (
  `id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `name` varchar(128) DEFAULT NULL,
  PRIMARY KEY (`id`)
) DEFAULT CHARSET=utf8;

#`id` and `end_id` match the quote ids embedded in the ESV text by the ESV API
#`who_id` is the BBCCCVVV, followed by a period, followed by a zero-padded offset (starting at "01") of each word in the verse. It indicates where the speaker is in the text
#`who_normalized` is the name of the speaker. A leading @ indicates who is being quoted in an inner quote, not who is speaking. In Gen 1:3, for example: "Did God actually say, 'You shall not eat of any tree in the garden'?" The outer quote is attributed to Satan, and the inner quote is attributed to @God. A leading # indicates an uncertain speaker (#audience, #author, #citation, #people, #person, #inscription, #saying, #unnamed, #unspecified, #woman)
#`is_continued` indicates that the quote id is part of a previously open quote that crosses paragraphs
#`is_inner` indicates that the quote id is inside another quote
#`is_auto` indicates that the quote was automatically assigned by the ESV translation team (red-letter tagging for the words of Christ)
CREATE TABLE `quote_speakers` (
  `id` varchar(10) NOT NULL,
  `end_id` varchar(10) NOT NULL DEFAULT '',
  `who_id` varchar(255) DEFAULT NULL,
  `who_normalized` varchar(255) DEFAULT NULL,
  `is_continued` tinyint(1) DEFAULT NULL,
  `is_inner` tinyint(1) NOT NULL DEFAULT '0',
  `is_auto` tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `who_id` (`who_id`)
) DEFAULT CHARSET=utf8;

#`word` is the word as it appears in the ESV text
#`occurrences` is the number of times it appears in the ESV text
#`unit_id` is the BBCCCVVV where the word occurs
#`position` is 1 if it refers to the first time the word appears in that verse and increments every time thereafter
#`proper_name` is 1 if it's a proper name (as opposed to just a capitalized word)
#`category` is the type of proper name it is: book-title, divine-name, geographic, holiday, language, member-of-people-group, messianic, month, non-human, object, pagan-god, people-group, person, psalm-title, religion, ritual, title, tribe
#`phrase` is the text of the full name if it's part of a phrase (like "John the Baptist")
#`tentative` is whether the identification is unsure
CREATE TABLE `word_capitals` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `word` varchar(32) NOT NULL,
  `occurrences` smallint(6) NOT NULL DEFAULT '0',
  `unit_id` int(8) unsigned zerofill NOT NULL DEFAULT '00000000',
  `position` tinyint(3) unsigned NOT NULL DEFAULT '0',
  `proper_name` tinyint(4) DEFAULT NULL,
  `category` varchar(64) DEFAULT NULL,
  `phrase` varchar(255) DEFAULT NULL,
  `tentative` tinyint(4) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `category` (`category`),
  KEY `proper_name` (`proper_name`),
  KEY `unit_id` (`unit_id`)
) DEFAULT CHARSET=utf8;

# To import the data, you should be able to use MySQL's LOAD DATA INFILE command, or you can parse the files yourself (the fields are tab-delimited, with "\N" indicating a null value)